@@ -29,8 +29,7 @@
 CreateColorGui_test::CreateColorGui_test(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *vbox = new QVBoxLayout;
-    setLayout(vbox);
+    QVBoxLayout *vbox = new QVBoxLayout(this);
     mListWidget = new QListWidget;
     vbox->addWidget(mListWidget);
     createListWidgetItem();
@@ -38,7 +37,6 @@ CreateColorGui_test::CreateColorGui_test(QWidget *parent)
 
 CreateColorGui_test::~CreateColorGui_test()
 {
-
 }
 
 void CreateColorGui_test::createListWidgetItem()
@@ -57,12 +55,11 @@ void CreateColorGui_test::createListWidgetItem()
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("CreateColorGui_test"), i18n("CreateColorGui_test"), QStringLiteral("1.0"));
+    KAboutData aboutData(QStringLiteral("CreateColorGui_test"), i18n(
+                             "CreateColorGui_test"), QStringLiteral("1.0"));
     aboutData.setShortDescription(i18n("Test creating color"));
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
-    parser.addVersionOption();
-    parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
